%define _buildid .8

%global py26nvr python26-rsa-%{version}-%{release}
%global py26builddir %{_builddir}/%{py26nvr}
%global py26doc ../%{py26nvr}

%global py27nvr python27-rsa-%{version}-%{release}
%global py27builddir %{_builddir}/%{py27nvr}
%global py27doc ../%{py27nvr}

%bcond_without tests # with

%global upstream_name rsa

Name: python-rsa
Version: 3.4.1
Release: 1%{?_buildid}%{?dist}
Summary: Pure-Python RSA implementation
Group: Development/Libraries
License: ASL 2.0
URL: http://stuvel.eu/rsa
Source0:        https://pypi.python.org/packages/source/r/rsa/rsa-%{version}.tar.gz
BuildArch: noarch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires: python26
BuildRequires: python27

%description
Python-RSA is a pure-Python RSA implementation. It supports encryption
and decryption, signing and verifying signatures, and key generation
according to PKCS#1 version 1.5. It can be used as a Python library as
well as on the command-line.

%package -n python26-rsa
Summary: Pure-Python RSA implementation
BuildRequires: python26-devel
BuildRequires: python26-setuptools
BuildRequires: python26-pyasn1 >= 0.1.3
BuildRequires: python26-pytest
Requires: python26-pyasn1 >= 0.1.3
Requires: python26-setuptools
Provides: python-rsa = %{version}-%{release}
Obsoletes: python-rsa <= 3.1.2-4.3.amzn1

%description -n python26-rsa
Python-RSA is a pure-Python RSA implementation. It supports encryption
and decryption, signing and verifying signatures, and key generation
according to PKCS#1 version 1.5. It can be used as a Python library as
well as on the command-line.

This package is meant to be used with Python 2.6.

%package -n python27-rsa
Summary: Pure-Python RSA implementation
BuildRequires: python27-devel
BuildRequires: python27-setuptools
BuildRequires: python27-pyasn1 >= 0.1.3
BuildRequires: python27-pytest
Requires: python27-pyasn1 >= 0.1.3
Requires: python27-setuptools

%description -n python27-rsa
Python-RSA is a pure-Python RSA implementation. It supports encryption
and decryption, signing and verifying signatures, and key generation
according to PKCS#1 version 1.5. It can be used as a Python library as
well as on the command-line.

This package is meant to be used with Python 2.7.

%prep
%setup -q -n %{upstream_name}-%{version}

%build
rm -rf %{py26builddir}
mkdir -p %{py26builddir}
cp -a * %{py26builddir}
pushd %{py26builddir}
CFLAGS="$RPM_OPT_FLAGS" %{__python26} setup.py build 
popd

rm -rf %{py27builddir}
mkdir -p %{py27builddir}
cp -a * %{py27builddir}
pushd %{py27builddir}
CFLAGS="$RPM_OPT_FLAGS" %{__python27} setup.py build 
popd

%install
rm -rf %{buildroot}

pushd %{py26builddir}
%{__python26} setup.py install -O1 --skip-build --root %{buildroot} --install-layout=amzn
popd

for script in pyrsa-{decrypt,decrypt-bigfile,encrypt,encrypt-bigfile,keygen,priv2pub,sign,verify}; do
   cp -a %{buildroot}%{_bindir}/${script}{,-2.6}
   %{__python26_shebang} %{buildroot}%{_bindir}/${script}-2.6
done

pushd %{py27builddir}
%{__python27} setup.py install -O1 --skip-build --root %{buildroot} --install-layout=amzn
popd

for script in pyrsa-{decrypt,decrypt-bigfile,encrypt,encrypt-bigfile,keygen,priv2pub,sign,verify}; do
   cp -a %{buildroot}%{_bindir}/${script}{,-2.7}
   %{__python27_shebang} %{buildroot}%{_bindir}/${script}-2.7
done

pushd %{buildroot}%{_bindir}
for script in pyrsa-{decrypt,decrypt-bigfile,encrypt,encrypt-bigfile,keygen,priv2pub,sign,verify}; do
   rm ${script}
   ln -s ${script}-2.6 ${script}
done
popd

%check
%if %{with tests}
pushd %{py26builddir}
py.test-2.6 -v
popd
pushd %{py27builddir}
py.test-2.7 -v
popd
%endif

%clean
rm -rf %{buildroot}
rm -rf %{py26builddir}
rm -rf %{py27builddir}

%files -n python26-rsa
%doc README.md LICENSE
%{python26_sitelib}/*
%{_bindir}/pyrsa-decrypt
%{_bindir}/pyrsa-decrypt-bigfile
%{_bindir}/pyrsa-encrypt
%{_bindir}/pyrsa-encrypt-bigfile
%{_bindir}/pyrsa-keygen
%{_bindir}/pyrsa-priv2pub
%{_bindir}/pyrsa-sign
%{_bindir}/pyrsa-verify
%{_bindir}/pyrsa-decrypt-2.6
%{_bindir}/pyrsa-decrypt-bigfile-2.6
%{_bindir}/pyrsa-encrypt-2.6
%{_bindir}/pyrsa-encrypt-bigfile-2.6
%{_bindir}/pyrsa-keygen-2.6
%{_bindir}/pyrsa-priv2pub-2.6
%{_bindir}/pyrsa-sign-2.6
%{_bindir}/pyrsa-verify-2.6

%files -n python27-rsa
%doc README.md LICENSE
%{python27_sitelib}/*
%{_bindir}/pyrsa-decrypt-2.7
%{_bindir}/pyrsa-decrypt-bigfile-2.7
%{_bindir}/pyrsa-encrypt-2.7
%{_bindir}/pyrsa-encrypt-bigfile-2.7
%{_bindir}/pyrsa-keygen-2.7
%{_bindir}/pyrsa-priv2pub-2.7
%{_bindir}/pyrsa-sign-2.7
%{_bindir}/pyrsa-verify-2.7

%changelog
* Thu Apr 14 2016 Amazon Linux AMI <amazon-linux-ami@amazon.com>
- import source package EPEL7/python-rsa-3.4.1-1.el7

* Sat Mar 26 2016 Fabio Alessandro Locati <fabio@locati.cc> - 3.4.1-1
- Update to 3.4.1

* Fri Mar 18 2016 Fabio Alessandro Locati <fabio@locati.cc> - 3.4-1
- Bump to 3.4
- Remove the patch that is no longer needed since it has been merged upstream

* Tue Feb 09 2016 Fabio Alessandro Locati <fabio@locati.cc> - 3.3-5
- Fix bug #1305644

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 3.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Feb 02 2016 Fabio Alessandro Locati <fabio@locati.cc> - 3.3-3
- Fix bug #1303660

* Wed Jan 27 2016 Amazon Linux AMI <amazon-linux-ami@amazon.com>
- import source package EPEL7/python-rsa-3.3-2.el7

* Wed Jan 13 2016 Fabio Alessandro Locati <fabio@locati.cc> - 3.3-2
- Fix for EL6 and EPEL7

* Wed Jan 13 2016 Fabio Alessandro Locati <fabio@locati.cc> - 3.3-1
- Update to current upstream
- Fix CVE-2016-1494
- Bring spec compliant with current policy

* Tue Dec  8 2015 Paul Howarth <paul@city-fan.org> - 3.1.4-3
- Fix FTBFS (Debian Bug #804430)
- Run the tests for both python2 and python3

* Tue Nov 10 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.1.4-2
- Rebuilt for https://fedoraproject.org/wiki/Changes/python3.5

* Tue Oct 13 2015 Paul Howarth <paul@city-fan.org> - 3.1.4-1
- Update to 3.1.4 (#1226667)

* Fri Oct 9 2015 Ian Weller <iweller@amazon.com>
- Add Requires on pyasn1 module

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.1.1-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Wed Feb 4 2015 Tom Kirchner <tjk@amazon.com>
- Build for multiple python versions

* Fri Jul 25 2014 Lubomir Rintel <lkundrak@v3.sk> - 3.1.1-6
- Add Python 3 subpackage

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.1.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sat Mar 15 2014 Cristian Gafton <gafton@amazon.com>
- import source package EPEL6/python-rsa-3.1.1-5.el6

* Fri Mar 14 2014 Cristian Gafton <gafton@amazon.com>
- setup complete for package python-rsa

* Thu Sep 19 2013 Lee Trager <ltrager@amazon.com>
- Update to 3.1.2 from upstream

* Tue Sep 10 2013 Lee Trager <ltrager@amazon.com>
- Requires python-pyasn1 >= 0.1.3

* Mon Sep 9 2013 Lee Trager <ltrager@amazon.com>
- import source package F20/python-rsa-3.1.1-4.fc20
- setup complete for package python-rsa

* Mon Aug 05 2013 Yohan Graterol <yohangraterol92@gmail.com> - 3.1.1-4
- Fix build in F20

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.1.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sun May 26 2013 Yohan Graterol <yohangraterol92@gmail.com> - 3.1.1-2
- Change license name, remove MANIFEST.in

* Sun May 19 2013 Yohan Graterol <yohangraterol92@gmail.com> - 3.1.1-1
- Initial packaging
